const CompressionPlugin = require('compression-webpack-plugin');
const zlib = require("zlib");


module.exports = (api, options) => {
  const compressions = (options.pluginOptions || {}).compression || {
    brotli: {
      filename: '[file].br[query]',
      algorithm: 'brotliCompress',
      include: /\.(js|css|html|svg|json)(\?.*)?$/i,
      compressionOptions: {
        params: {
          [zlib.constants.BROTLI_PARAM_QUALITY]: 11,
        },
      },
      minRatio: 0.8,
    },
    gzip: {
      filename: '[file].gz[query]',
      algorithm: 'gzip',
      include: /\.(js|css|html|svg|json)(\?.*)?$/i,
      minRatio: 0.8,
    }
  };

  const modes = compressions.modes || ['production'];
  if (Array.isArray(modes) && modes.indexOf(process.env.NODE_ENV) >= 0) {
    for (let compression in compressions) {
      if (compression !== 'modes') {
        api.chainWebpack(webpackConfig => {
          webpackConfig
            .plugin(compression + "-compression")
            .use(CompressionPlugin)
            .init(Plugin => new Plugin(compressions[compression]));
        });
      }
    }
  }
};
